@@ -1,12 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "khoj" "1.42.10"
+(define-package "khoj" "20250916.917"
   "Your Second Brain."
   '((emacs     "27.1")
     (transient "0.3.0")
     (dash      "2.19.1"))
   :url "https://github.com/khoj-ai/khoj/tree/master/src/interface/emacs"
-  :commit "a6fe2d2fbdae2032eed488a27e7317dcff036555"
-  :revdesc "a6fe2d2fbdae"
+  :commit "6ac2280e4117421c1c162a4a0a2ecfa16351dc36"
+  :revdesc "6ac2280e4117"
   :keywords '("search" "chat" "ai" "org-mode" "outlines" "markdown" "pdf" "image")
   :authors '(("Debanjum Singh Solanky" . "debanjum@khoj.dev")
              ("Saba Imran" . "saba@khoj.dev"))
